package Weed::Field::SFNode;
use strict;
use warnings;

our $VERSION = '0.0011';

use Weed;

our $DESCRIPTION = 'SFNode : X3DField { }';

1;
__END__
